const path = require('path')
const { CleanWebpackPlugin } = require('clean-webpack-plugin')
const { dependencies, devDependencies } = require('./package.json')

let config = {
  mode: 'production',
  entry: path.join(__dirname, 'src/index.js'),
  output: {
    filename: 'index.js',
    path: path.join(__dirname, 'build'),
    libraryTarget: 'commonjs2'
  },
  resolve: {
    extensions: ['.js'],
    alias: {
      'src': path.join(__dirname, 'src'),
      '#package': path.join(__dirname, 'package.json')
    }
  },
  module: {
    rules: [
      {
        test: /\.js$/,
        exclude: path.join(__dirname, 'node_modules'),
        use: 'babel-loader'
      },
      {
        test: /\.js$/,
        enforce: 'pre',
        exclude: /node_modules/,
        use: {
          loader: 'eslint-loader',
          options: {
            formatter: require('eslint-friendly-formatter')
          }
        }
      }
    ]
  },
  target: 'node',
  externals: [
    ...Object.keys(Object.assign(dependencies, devDependencies) || {})
  ],
  plugins: [
    new CleanWebpackPlugin()
  ]
}

module.exports = config
